@@ -22,11 +22,14 @@ class ModelMonitor(AbstractApiClass):
             latestPredictionMetricVersionId (str): Lastest prediction metric instance for decile and other analysis
             metricConfigs (dict): Configurations for model monitor
             metricTypes (dict): List of metric types
+            modelId (unique string identifiers): Model ID that this model monitor is monitoring.
+            starred (bool): Whether this model monitor is starred.
+            batchPredictionId (str): 
             latestMonitorModelVersion (ModelMonitorVersion): The latest model monitor version.
             refreshSchedules (RefreshSchedule): List of refresh schedules that indicate when the next model version will be trained.
     """
 
-    def __init__(self, client, modelMonitorId=None, name=None, createdAt=None, projectId=None, trainingFeatureGroupId=None, predictionFeatureGroupId=None, alertConfig=None, biasMetricId=None, latestBiasMetricVersionId=None, predictionMetricId=None, latestPredictionMetricVersionId=None, metricConfigs=None, metricTypes=None, refreshSchedules={}, latestMonitorModelVersion={}):
+    def __init__(self, client, modelMonitorId=None, name=None, createdAt=None, projectId=None, trainingFeatureGroupId=None, predictionFeatureGroupId=None, alertConfig=None, biasMetricId=None, latestBiasMetricVersionId=None, predictionMetricId=None, latestPredictionMetricVersionId=None, metricConfigs=None, metricTypes=None, modelId=None, starred=None, batchPredictionId=None, refreshSchedules={}, latestMonitorModelVersion={}):
         super().__init__(client, modelMonitorId)
         self.model_monitor_id = modelMonitorId
         self.name = name
@@ -41,13 +44,16 @@ class ModelMonitor(AbstractApiClass):
         self.latest_prediction_metric_version_id = latestPredictionMetricVersionId
         self.metric_configs = metricConfigs
         self.metric_types = metricTypes
+        self.model_id = modelId
+        self.starred = starred
+        self.batch_prediction_id = batchPredictionId
         self.refresh_schedules = client._build_class(
             RefreshSchedule, refreshSchedules)
         self.latest_monitor_model_version = client._build_class(
             ModelMonitorVersion, latestMonitorModelVersion)
 
     def __repr__(self):
-        return f"ModelMonitor(model_monitor_id={repr(self.model_monitor_id)},\n  name={repr(self.name)},\n  created_at={repr(self.created_at)},\n  project_id={repr(self.project_id)},\n  training_feature_group_id={repr(self.training_feature_group_id)},\n  prediction_feature_group_id={repr(self.prediction_feature_group_id)},\n  alert_config={repr(self.alert_config)},\n  bias_metric_id={repr(self.bias_metric_id)},\n  latest_bias_metric_version_id={repr(self.latest_bias_metric_version_id)},\n  prediction_metric_id={repr(self.prediction_metric_id)},\n  latest_prediction_metric_version_id={repr(self.latest_prediction_metric_version_id)},\n  metric_configs={repr(self.metric_configs)},\n  metric_types={repr(self.metric_types)},\n  refresh_schedules={repr(self.refresh_schedules)},\n  latest_monitor_model_version={repr(self.latest_monitor_model_version)})"
+        return f"ModelMonitor(model_monitor_id={repr(self.model_monitor_id)},\n  name={repr(self.name)},\n  created_at={repr(self.created_at)},\n  project_id={repr(self.project_id)},\n  training_feature_group_id={repr(self.training_feature_group_id)},\n  prediction_feature_group_id={repr(self.prediction_feature_group_id)},\n  alert_config={repr(self.alert_config)},\n  bias_metric_id={repr(self.bias_metric_id)},\n  latest_bias_metric_version_id={repr(self.latest_bias_metric_version_id)},\n  prediction_metric_id={repr(self.prediction_metric_id)},\n  latest_prediction_metric_version_id={repr(self.latest_prediction_metric_version_id)},\n  metric_configs={repr(self.metric_configs)},\n  metric_types={repr(self.metric_types)},\n  model_id={repr(self.model_id)},\n  starred={repr(self.starred)},\n  batch_prediction_id={repr(self.batch_prediction_id)},\n  refresh_schedules={repr(self.refresh_schedules)},\n  latest_monitor_model_version={repr(self.latest_monitor_model_version)})"
 
     def to_dict(self):
         """
@@ -56,7 +62,7 @@ class ModelMonitor(AbstractApiClass):
         Returns:
             dict: The dict value representation of the class parameters
         """
-        return {'model_monitor_id': self.model_monitor_id, 'name': self.name, 'created_at': self.created_at, 'project_id': self.project_id, 'training_feature_group_id': self.training_feature_group_id, 'prediction_feature_group_id': self.prediction_feature_group_id, 'alert_config': self.alert_config, 'bias_metric_id': self.bias_metric_id, 'latest_bias_metric_version_id': self.latest_bias_metric_version_id, 'prediction_metric_id': self.prediction_metric_id, 'latest_prediction_metric_version_id': self.latest_prediction_metric_version_id, 'metric_configs': self.metric_configs, 'metric_types': self.metric_types, 'refresh_schedules': self._get_attribute_as_dict(self.refresh_schedules), 'latest_monitor_model_version': self._get_attribute_as_dict(self.latest_monitor_model_version)}
+        return {'model_monitor_id': self.model_monitor_id, 'name': self.name, 'created_at': self.created_at, 'project_id': self.project_id, 'training_feature_group_id': self.training_feature_group_id, 'prediction_feature_group_id': self.prediction_feature_group_id, 'alert_config': self.alert_config, 'bias_metric_id': self.bias_metric_id, 'latest_bias_metric_version_id': self.latest_bias_metric_version_id, 'prediction_metric_id': self.prediction_metric_id, 'latest_prediction_metric_version_id': self.latest_prediction_metric_version_id, 'metric_configs': self.metric_configs, 'metric_types': self.metric_types, 'model_id': self.model_id, 'starred': self.starred, 'batch_prediction_id': self.batch_prediction_id, 'refresh_schedules': self._get_attribute_as_dict(self.refresh_schedules), 'latest_monitor_model_version': self._get_attribute_as_dict(self.latest_monitor_model_version)}
 
     def rerun(self):
         """
@@ -94,13 +100,13 @@ class ModelMonitor(AbstractApiClass):
 
     def get_summary(self):
         """
-
+        Gets the summary of a model monitor across versions.
 
         Args:
-            model_monitor_id (str): 
+            model_monitor_id (str): The unique ID associated with the model monitor.
 
         Returns:
-            ModelMonitorSummary: None
+            ModelMonitorSummary: An object describing integrity, bias violations, model accuracy, and drift for a model monitor.
         """
         return self.client.get_model_monitor_summary(self.model_monitor_id)
 
